.onLoad <- function(lib, pkg) {
	#library.dynam("sdcTable", pkg, lib)
	packageStartupMessage("Package sdcTable 0.9.9 has been loaded!\n")
}
